@@ -1,14 +1,22 @@
-import astroid
-from astroid.builder import AstroidBuilder
-from collections import defaultdict
-from python_ta.typecheck.base import parse_annotations, \
-    _gorg, class_callable, accept_failable, _node_to_type, _collect_tvars, TypeFailFunction
 import os
+from collections import defaultdict
 from typing import *
 from typing import Any, ForwardRef
 
+from astroid import nodes
+from astroid.builder import AstroidBuilder
 
-TYPE_SHED_PATH = os.path.join(os.path.dirname(__file__), 'typeshed', 'builtins.pyi')
+from python_ta.typecheck.base import (
+    TypeFailFunction,
+    _collect_tvars,
+    _gorg,
+    _node_to_type,
+    accept_failable,
+    class_callable,
+    parse_annotations,
+)
+
+TYPE_SHED_PATH = os.path.join(os.path.dirname(__file__), "typeshed", "builtins.pyi")
 
 
 class TypeStore:
@@ -29,32 +37,37 @@ class TypeStore:
 
         # Add in initializers
         for klass_name, methods in self.classes.items():
-            if '__init__' in methods:
-                self.functions[klass_name] = [class_callable(init) for init, _ in methods['__init__']]
+            if "__init__" in methods:
+                self.functions[klass_name] = [
+                    class_callable(init) for init, _ in methods["__init__"]
+                ]
 
-    def _parse_classes(self, module: astroid.Module) -> None:
+    def _parse_classes(self, module: nodes.Module) -> None:
         """Parse the class definitions from typeshed."""
-        for class_def in module.nodes_of_class(astroid.ClassDef):
+        for class_def in module.nodes_of_class(nodes.ClassDef):
             tvars = []
-            self.classes[class_def.name]['__bases'] = []
+            self.classes[class_def.name]["__bases"] = []
             for base in class_def.bases:
                 base_type = _node_to_type(base)
-                self.classes[class_def.name]['__pyta_tvars'] = \
-                    [tv.__name__ for tv in _collect_tvars(base_type)]
-                self.classes[class_def.name]['__bases'].append(base_type)
-            self.classes[class_def.name]['__mro'] = [cls.name for cls in class_def.mro()]
-            for node in (nodes[0] for nodes in class_def.locals.values()
-                         if isinstance(nodes[0], astroid.AssignName) and
-                         isinstance(nodes[0].parent, astroid.AnnAssign)):
+                self.classes[class_def.name]["__pyta_tvars"] = [
+                    tv.__name__ for tv in _collect_tvars(base_type)
+                ]
+                self.classes[class_def.name]["__bases"].append(base_type)
+            self.classes[class_def.name]["__mro"] = [cls.name for cls in class_def.mro()]
+            for node in (
+                nodes[0]
+                for nodes in class_def.locals.values()
+                if isinstance(nodes[0], nodes.AssignName)
+                and isinstance(nodes[0].parent, nodes.AnnAssign)
+            ):
                 self.classes[class_def.name][node.name] = parse_annotations(node, tvars)
 
-
-    def _parse_functions(self, module: astroid.Module) -> None:
+    def _parse_functions(self, module: nodes.Module) -> None:
         """Parse the function definitions from typeshed."""
-        for function_def in module.nodes_of_class(astroid.FunctionDef):
-            in_class = isinstance(function_def.parent, astroid.ClassDef)
+        for function_def in module.nodes_of_class(nodes.FunctionDef):
+            in_class = isinstance(function_def.parent, nodes.ClassDef)
             if in_class:
-                tvars = self.classes[function_def.parent.name]['__pyta_tvars']
+                tvars = self.classes[function_def.parent.name]["__pyta_tvars"]
             else:
                 tvars = []
             f_type = parse_annotations(function_def, tvars)
@@ -71,8 +84,9 @@ class TypeStore:
             for func_type in func_types_list:
                 if len(args) != len(func_type.__args__) - 1:
                     continue
-                if self.type_constraints.can_unify(Callable[list(func_type.__args__[:-1]), Any],
-                                                   Callable[list(args), Any]):
+                if self.type_constraints.can_unify(
+                    Callable[list(func_type.__args__[:-1]), Any], Callable[list(args), Any]
+                ):
                     return func_type
             raise KeyError
 
@@ -84,12 +98,16 @@ class TypeStore:
         """
         if args:
             # First try to do a direct lookup.
-            if isinstance(args[0], ForwardRef) and operator in self.classes[args[0].__forward_arg__]:
+            if (
+                isinstance(args[0], ForwardRef)
+                and operator in self.classes[args[0].__forward_arg__]
+            ):
                 for func_type, _ in self.classes[args[0].__forward_arg__][operator]:
                     if len(args) != len(func_type.__args__) - 1:
                         continue
-                    if self.type_constraints.can_unify(Callable[list(args), Any],
-                                                       Callable[list(func_type.__args__[:-1]), Any]):
+                    if self.type_constraints.can_unify(
+                        Callable[list(args), Any], Callable[list(func_type.__args__[:-1]), Any]
+                    ):
                         return func_type
 
             # If that doesn't work, fall back on a brute force search.
@@ -97,50 +115,66 @@ class TypeStore:
             for func_type, _ in func_types_list:
                 if len(args) != len(func_type.__args__) - 1:
                     continue
-                if self.type_constraints.can_unify(Callable[list(args), Any],
-                                                   Callable[list(func_type.__args__[:-1]), Any]):
+                if self.type_constraints.can_unify(
+                    Callable[list(args), Any], Callable[list(func_type.__args__[:-1]), Any]
+                ):
                     return func_type
             return TypeFailFunction(tuple(func_types_list), None, node)
 
     def is_descendant(self, child: type, ancestor: type) -> bool:
-        if (getattr(child, '__origin__', None) is Union or
-                getattr(ancestor, '__origin__', None) is Union):
+        if (
+            getattr(child, "__origin__", None) is Union
+            or getattr(ancestor, "__origin__", None) is Union
+        ):
             return self.type_constraints.can_unify(child, ancestor)
         if ancestor == object or ancestor == Any or child == Any:
             return True
 
         if isinstance(child, ForwardRef):
             child_name = child.__forward_arg__
-        elif hasattr(child, '__origin__'):
+        elif hasattr(child, "__origin__"):
             child_name = child.__origin__.__name__
         else:
             child_name = child.__name__
 
-        if hasattr(child, '__mro__') and ancestor in child.__mro__:
+        if hasattr(child, "__mro__") and ancestor in child.__mro__:
             return True
-        elif hasattr(ancestor, '__mro__') and Protocol in ancestor.__mro__ and issubclass(child, ancestor):
+        elif (
+            hasattr(ancestor, "__mro__")
+            and Protocol in ancestor.__mro__
+            and issubclass(child, ancestor)
+        ):
             return True
-        elif hasattr(child, '__orig_bases__'):
+        elif hasattr(child, "__orig_bases__"):
             for base in child.__orig_bases__:
-                if isinstance(base, _GenericAlias) and isinstance(ancestor, _GenericAlias) and \
-                   issubclass(_gorg(base), _gorg(ancestor)) and \
-                   all([self.type_constraints.can_unify(a1, a2) for a1, a2 in
-                         zip(base.__args__, ancestor.__args__)]):
+                if (
+                    isinstance(base, _GenericAlias)
+                    and isinstance(ancestor, _GenericAlias)
+                    and issubclass(_gorg(base), _gorg(ancestor))
+                    and all(
+                        [
+                            self.type_constraints.can_unify(a1, a2)
+                            for a1, a2 in zip(base.__args__, ancestor.__args__)
+                        ]
+                    )
+                ):
                     return True
         elif child_name in self.classes:
-            for base in self.classes[child_name]['__bases']:
-                if self.type_constraints.can_unify(base, ancestor) or \
-                        self.is_descendant(base, ancestor):
+            for base in self.classes[child_name]["__bases"]:
+                if self.type_constraints.can_unify(base, ancestor) or self.is_descendant(
+                    base, ancestor
+                ):
                     # TODO: make sure it is safe to alter type_constraints here
                     self.type_constraints.unify(base, ancestor)
                     return True
         return False
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     # Display the TypeStore parsed from typeshed.
     ts = TypeStore(None)
     import pprint
+
     pprint.pprint(ts.classes)
-    pprint.pprint(ts.methods['__iter__'])
+    pprint.pprint(ts.methods["__iter__"])
     pprint.pprint(ts.functions)
